@@ -92,7 +92,8 @@ def _get_options():
     cfg_files = nose.core.all_config_files()
     manager = nose.core.DefaultPluginManager()
     config = nose.core.Config(env=os.environ, files=cfg_files, plugins=manager)
-    options = config.getParser().option_list
+    config.plugins.addPlugins(list(_get_plugins_from_settings()))
+    options = config.getParser()._get_all_options()
     django_opts = [opt.dest for opt in BaseCommand.option_list] + ['version']
     return tuple(o for o in options if o.dest not in django_opts and
                                        o.action != 'help')
